<!--[if lt IE 7]>
  <div id="ie6-warning">
    <h2>Please note: your web browser is out of date</h2>
    <p>
      It looks like you're using Internet Explorer 6. This is a very old
      browser which does not offer full support for modern websites.
    </p>
    <p>
      Unfortunately this means that this website will not work on
      your computer.
    </p>
    <p>
      Don't miss out though! To view the site (and get a better experience from
      many other websites), simply upgrade to
      <a href="http://www.microsoft.com/windows/Internet-explorer/default.aspx">Internet
      Explorer 8</a> or download an alternative browser such as
      <a href="http://www.mozilla.com/en-US/firefox/firefox.html">Firefox</a>,
      <a href="http://www.opera.com/browser/download/">Opera</a>,
      <a href="http://www.apple.com/safari/download/">Safari</a>, or
      <a href="http://www.google.co.uk/chrome">Google Chrome</a>.
    </p>
    <p>
      All of these browsers are free. If you're using a PC at work, you may
      need to contact your IT administrator.
    </p>
  </div>
<![endif]-->
