<h1>Help</h1>
<p>So you've stumbled upon this site and are wondering what it all means, or 
perhaps you've been used to the old version and are now completely bemused by
the Javascript and revised layout.</p>
<p><a href="/page/help.html">Click here</a> for a longer explanation of what 
has changed and how to best make use of the site for your purposes.</p>
