<?xml version="1.0"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en-gb" lang="en-gb">
<head>

[% body = PROCESS $content %]

[% 
    base_url   = 'static.cpantesters.org' ;
    base_href  = 'http://static.cpantesters.org' ;
    base_title = 'CPAN Testers Reports' ;
%]

  <title>[% base_title %]: [% htmltitle || title | html %]</title>

  <meta http-equiv="Content-Type"         content="text/html; charset=UTF-8" />
  <meta http-equiv="Content-Language"     content="en-gb" />
  <meta http-equiv="Content-Style-Type"   content="text/css" />
  <meta http-equiv="Content-Script-Type"  content="text/javascript" />

  <meta name="Generator"    content="Labyrinth" />
  <meta name="copyright"    content="Copyright (C) 2007-2013 CPAN Testers" />
  <meta name="title"        content="[% base_title %]" />
  <meta name="author"       content="Barbie" />
  <meta name="language"     content="en" />
  <meta name="keywords"     content="perl, cpan, test, testing, tester, testers, reports, smoke, smoker, black box, automated, automation" />
  <meta name="description"  content="Report listings of distributions and authors from reports submitted by the CPAN Testers community, who automatically black box test submissions to Perl's CPAN code repository" />

  <link rel="stylesheet" type="text/css" media="screen,projection,print" href="/css/layout2_setup.css" />
  <link rel="stylesheet" type="text/css" media="screen,projection,print" href="/css/layout2_text.css" />

[% IF rss %]<link  rel="alternate" type="application/rss+xml" title="CPAN Testers RSS" href="[% rss %]" />[% END %]
[% IF rss2 %]<link rel="alternate" type="application/rss+xml" title="CPAN Testers RSS - NO PASS" href="[% rss2 %]" />[% END %]

  [% INCLUDE "public/analytics-23.html" %]

  <script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1.9.1/jquery.min.js"></script>

<!--
  Site Layout, Design &amp; Development by Miss Barbell Productions
  Original CSS/XHTML Template Design by Wolfgang.

  Valid XHTML 1.0 - http://validator.w3.org/check?uri=referer
  Powered by LAMP (Linux, Apache, MySQL &amp; Perl) technologies.
  Produced by LABYRINTH, a state of the art Website Management System
  available from Miss Barbell Productions.
  For more information contact Barbie <barbie@missbarbell.co.uk>

  Smoke Box image copyright (c) Tyson Ibele 2004 (http://www.tysonibele.com/Main/gallery.htm)
-->

</head>
<body [% onload %] >

<body>
  <!-- Main Page Container -->
  <div class="page-container">

    <!-- For alternative headers START PASTE here -->

    <!-- A. HEADER -->      
    <div class="header">
      
      <!-- A.1 HEADER TOP -->
      <div class="header-middle">

        <!-- Sitelogo and sitename -->
        <div class="sitename">
          <h1><a href="/">[% base_title %]</a></h1>
          <h3>[% base_url %]</h3>
          <h2>[% htmltitle || title %]</h2>
        </div>
      </div>
    
        [% INCLUDE "public/box-sites.html" %]

      <!-- A.4 HEADER BREADCRUMBS -->

      <!-- Breadcrumbs -->
      <div class="header-breadcrumbs">
        <ul>
          <li><a href="/">Home</a></li>
          [% IF crumb3_name %]<li><a href="[% crumb3_href %]">[% crumb3_name %]</a></li>[% END %]
          [% IF crumb2_name %]<li><a href="[% crumb2_href %]">[% crumb2_name %]</a></li>[% END %]
          <li>[% crumb1_name %]</li>
        </ul>
      </div>
    </div>

    <!-- For alternative headers END PASTE here -->

    <!-- B. MAIN -->
    <div class="main">

      <!-- B.1 MAIN NAVIGATION -->
      <div class="main-navigation">

        <!-- Navigation Level 3 -->
        <div class="round-border-topright"></div>

          <h1>Menu</h1>
          <ul>
            <li><a href="/">Home</a></li>
            <li><a href="/page/help.html">Help</a></li>
            <li><a href="/page/about.html">About</a></li>
            <li><a href="http://www.cpantesters.org/user/login">Admin</a></li>
          </ul>
          <ul>
            <li><a href="http://www.cpantesters.org[% crosslink %]">Dynamic Website</a></li>
            <li><a href='http://stats.cpantesters.org/cpanmail.html'>Find A Tester</a></li>
          </ul>

          <h1>Javascript</h1>
          <p>This page is generated for those that use a browser that has Javascript disabled, or 
          support for Javascript is unimplemented.</p>
          <p>If you wish to view the more dynamic page, please 
          [% IF builder.distribution %]
          <a href="http://www.cpantesters.org/distro/[% builder.letter %]/[% builder.distribution | html %].html">click here</a>.</p>
          [% ELSIF builder.author %]
          <a href="http://www.cpantesters.org/author/[% builder.letter %]/[% builder.author | html %].html">click here</a>.</p>
          [% ELSE %]
          <a href="http://www.cpantesters.org">click here</a>.</p>
          [% END %]

        [% IF box_help  ; THEN ; INCLUDE "public/box-help.html"         ; END %]
        [% IF box_summ  ; THEN ; INCLUDE "cpan/box-summary-static.html" ; END %]

        [% INCLUDE "public/sidebar.html" %]
        [% INCLUDE "public/quote.html" %]

      </div>
 
      <!-- B.1 MAIN CONTENT -->
      <div class="main-content">

        <!-- Pagetitle -->
        <h1 class="pagetitle">[% title %]</h1>
        <div class="column1-unit">

          [% body %]

        </div>
        <hr class="clear-contentunit" />

      </div>
    </div>
      
    <!-- C. FOOTER AREA -->      
    [% INCLUDE "public/footer.html" %]

  </div> 

  <script type="text/javascript" src="/js/iheart.js"></script>

</body>
</html>
