[% 
    title = 'User Login' 

    box_help  = 1 ;

    crumb2_name = 'User' ;
    crumb2_href = '/' ;
    crumb1_name = 'Login' ;
%]

<form method="post" action="[% cgipath %]/pages.cgi">
<input type="hidden" name='act' value='user-logged' />
<input type="hidden" name='userid' value='[% data.userid %]' />

<table width="80%">
<tr><td>Email</td>
    <td><input type="text" name="cause" /></td>
    <td rowspan="2">
        Forgot your password? Not to worry, just enter your email
        and click the 'forgot my password' button below. We will then
        send you a new password.</td>
</tr>
<tr><td>Password</td>
    <td><input type="password" name="effect" /></td>
</tr>
<tr><td></td>
    <td><input type="submit" name="submit" value='LOGIN' /></td>
    <td><input type="submit" name="forgot" value='FORGOT MY PASSWORD' /></td>
</tr>
</table>

</form>

