[%
    title = 'Administration pages' ;

    crumb1_name = 'Index' ;
%]

<p>Please use the menu options above to select the administration you require.
<ul>
<li>Pages - Update site content pages
<li>Menus - Update the menu content
<li>Hits - A list of the top pages and photos being viewed by the public
<li>Users - A searchable list of the users registered within the system
<li>Logout - Logout of the admin site and return to the public site
</ul>

