<h1>Report Summary</h1>

[% IF builder.distribution %]

[% IF versions %]
<table>
[% FOREACH version = versions %]
<tr>
<td><a href="#[% versions_tag.$version -%]">[% version %]</a></td>
<td>
[%- s = summary.$version -%]
[%- IF s.ALL -%]
[%- IF s.PASS %]<img src="/images/layout/green.png" width="[% s.PASS * 80 / s.ALL %]" height="16" alt="PASS" />[% END -%]
[%- IF s.NA %]<img src="/images/layout/yellow.png" width="[% s.NA * 80 / s.ALL %]" height="16" alt="NA" />[% END -%]
[%- IF s.UNKNOWN %]<img src="/images/layout/yellow.png" width="[% s.UNKNOWN * 80 / s.ALL %]" height="16" alt="UNKNOWN" />[% END -%]
[%- IF s.FAIL %]<img src="/images/layout/red.png" width="[% s.FAIL * 80 / s.ALL %]" height="16" alt="FAIL" />[% END -%]
[% END %]
</td>
</tr>
[% END %]
</table>
[% END %]   

[% ELSE %]

[% IF distributions -%]
[% FOREACH d = distributions -%]
<h2><a href="#[% d.dist %]">[% d.dist %]</a></h2>
<p class="reportgraph">
[%- s = d.summary -%]
[%- IF s.ALL -%]
[%- IF s.PASS    %]<img src="/images/layout/green.png"  width="[% s.PASS    * 80 / s.ALL %]" height="16" alt="PASS"    />[% END -%]
[%- IF s.NA      %]<img src="/images/layout/yellow.png" width="[% s.NA      * 80 / s.ALL %]" height="16" alt="NA"      />[% END -%]
[%- IF s.UNKNOWN %]<img src="/images/layout/yellow.png" width="[% s.UNKNOWN * 80 / s.ALL %]" height="16" alt="UNKNOWN" />[% END -%]
[%- IF s.FAIL    %]<img src="/images/layout/red.png"    width="[% s.FAIL    * 80 / s.ALL %]" height="16" alt="FAIL"    />[% END -%]
[% END -%]
</p>
[% END -%]
[% END -%]

[% END %]      
