[% 
    IF users.data.userid ; THEN ; editmode = 'Edit' ; ELSE ; editmode = 'Add' ; END ;
    title = data.realname _ ' (Change Password)' ;

    crumb3_name = 'People' ;
    crumb3_href = '/cgi-bin/pages.cgi?act=user-admin' ;
    crumb2_name = data.realname ;
    crumb2_href = '/cgi-bin/pages.cgi?act=user-adminedit&amp;userid=' _ data.userid ;
    crumb1_name = 'Change Password' ;
%]


[% IF errmess %]<div class="box"><p style="alert">[% errmess %]</P></div>[% END %]
<div class="box">
    <p>Please use the following rules to create your new password:
    <ul>
    <li>Passwords should be [% minpasslen %] - [% maxpasslen %] characters in length.
    <li>Use more than one type from the upper case, lower case, numeral and symbol character types, e.g. 'Myword', 'smallword2' and 'L!TTLE' would all be fine.
    <li>Use at least 3 unique characters, i.e 'Eeeeee' is not allowed.
    <li>No whitespace characters allowed.
    </ul>
</div>

<form method="post" action="[% cgipath %]/pages.cgi">
<input type="hidden" name="act" value="user-adminchng" />
<input type="hidden" name="userid" value="[% user.userid %]" />

<div class="box">
    <table width="100%">
    <tr><th>User</th>
        <th></th>
        <td><strong>[% data.name %]</strong></td>
    </tr>
    <tr><th>New Password</th>
        <th></th>
        <td><input type="password" name="effect2" size="20" /></td>
    </tr>
    <tr><th>Retype New Password</th>
        <th></th>
        <td><input type="password" name="effect3" size="20" /></td>
    </tr>
	  <tr><td colspan="2"></td><td><input type="submit" name="submit" value="UPDATE" /></td></tr>
    </table>
</div>

</form>
