<?xml version="1.0"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en-gb" lang="en-gb">
<head>

[% body = PROCESS $content %]

<title>CPAN Testers Reports: [% htmltitle || title | html %]</title>

<meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1" />
<meta name="title"       content="CPAN Testers Reports" />
<meta name="author"      content="Barbie" />
<meta name="language"    content="en" />
<meta name="keywords"    content="perl, cpan, test, testing, tester, testers, reports, smoke, smoker, black box, automated, automation" />
<meta name="description" content="Report listings of distributions and authors from reports submitted by the CPAN Testers community, who automatically black box test submissions to Perl's CPAN code repository" />

<link rel="stylesheet" type="text/css" media="screen,projection,print" href="/css/layout2_setup.css" />
<link rel="stylesheet" type="text/css" media="screen,projection,print" href="/css/layout2_text.css" />

<script type="text/javascript">
var gaJsHost = (("https:" == document.location.protocol) ? "https://ssl." : "http://www.");
document.write(unescape("%3Cscript src='" + gaJsHost + "google-analytics.com/ga.js' type='text/javascript'%3E%3C/script%3E"));
</script>
<script type="text/javascript">
var pageTracker = _gat._getTracker("UA-1826389-16");
pageTracker._trackPageview();
</script>

<!--
    Site Layout, Design &amp; Development by Miss Barbell Productions

    Valid XHTML 1.0 - http://validator.w3.org/check?uri=referer
    Powered by LAMP (Linux, Apache, MySQL &amp; Perl) technologies.
    Produced by LABYRINTH, a state of the art Website Management System
    available from Miss Barbell Productions.
    For more information contact Barbie <barbie@missbarbell.co.uk>

-->

</head>
<body [% onload %] >
[% body %]
</body>
</html>
